# ----------------------------------------------------------------------------
# Frozen-string-literal: true
# Copyright: 2015-2016 Jordon Bedwell - MIT License
# Encoding: utf-8
# ----------------------------------------------------------------------------

require "rspec"

module RSpec
  module Helpers
    extend self

    # ------------------------------------------------------------------------
    # Silence the output of any method or command being ran.
    # ------------------------------------------------------------------------

    def silence_io(capture: false)
      _stdout = $stdout # OG
      _stderr = $stderr # OG
      $stdout = StringIO.new
      $stderr = StringIO.new

      if !capture
        yield
      else
        yield
        return {
          :stderr => $stderr.string,
          :stdout => $stdout.string
        }
      end
    ensure
      $stdout = _stdout
      $stderr = _stderr
    end

    # ------------------------------------------------------------------------
    # Wrap around `silence_io` making it easy to capture IO.
    # ------------------------------------------------------------------------

    def capture_io(&block)
      silence_io(:capture => true, &block)
    end

    #

    module ClassMethods

      # ----------------------------------------------------------------------
      # Include multiple contexts.
      # ----------------------------------------------------------------------

      def include_contexts(*contexts)
        contexts.map do |val|
          public_send(:include_context, val)
        end
      end
    end
  end
end

# ----------------------------------------------------------------------------

RSpec.configure do |config|
  config.extend  RSpec::Helpers::ClassMethods
  config.include RSpec::Helpers
end
